@@ -7,3 +7,7 @@ pub const DEFAULT_HOST: &str = "localhost:6600";
 pub const DETAILS_FORMAT: &str = "$title";
 pub const STATE_FORMAT: &str = "$artist / $album";
 pub const TIMESTAMP_MODE: &str = "elapsed";
+pub const LARGE_IMAGE: &str = "notes";
+pub const SMALL_IMAGE: &str = "notes";
+pub const LARGE_TEXT: &str = "";
+pub const SMALL_TEXT: &str = "";
